@@ -23,7 +23,7 @@ import com.beust.jcommander.Parameter;
 import java.util.List;
 import org.apache.pulsar.broker.resources.PulsarResources;
 import org.apache.pulsar.common.naming.NamespaceName;
-import org.apache.pulsar.common.util.CmdGenerateDocs;
+import org.apache.pulsar.docs.tools.CmdGenerateDocs;
 import org.apache.pulsar.metadata.api.MetadataStore;
 
 /**
@@ -40,11 +40,6 @@ public class PulsarInitialNamespaceSetup {
                 "--configuration-store" }, description = "Configuration Store connection string", required = true)
         private String configurationStore;
 
-        @Parameter(names = {"-cmscp",
-                "--configuration-metadata-store-config-path"}, description = "Configuration Metadata Store config path",
-                hidden = false)
-        private String configurationStoreConfigPath;
-
         @Parameter(names = {
                 "--zookeeper-session-timeout-ms"
         }, description = "Local zookeeper session timeout ms")
@@ -87,10 +82,8 @@ public class PulsarInitialNamespaceSetup {
             return 1;
         }
 
-        try (MetadataStore configStore = PulsarClusterMetadataSetup.initConfigMetadataStore(
-                arguments.configurationStore,
-                arguments.configurationStoreConfigPath,
-                arguments.zkSessionTimeoutMillis)) {
+        try (MetadataStore configStore = PulsarClusterMetadataSetup
+                .initConfigMetadataStore(arguments.configurationStore, arguments.zkSessionTimeoutMillis)) {
             PulsarResources pulsarResources = new PulsarResources(null, configStore);
             for (String namespace : arguments.namespaces) {
                 NamespaceName namespaceName = null;
